@@ -1,10 +1,14 @@
 from abc import ABCMeta, abstractmethod
 from logging import Logger, getLogger
-from selenium import webdriver
 from typing import Any
+
+from selenium import webdriver
+
 from ..exceptions import UnableActionException
 from ..user_information import UserInformation
 
+_logger: Logger = getLogger(__name__)
+
 
 class BaseOperator(metaclass=ABCMeta):
     """Base class for operator
@@ -14,7 +18,7 @@ class BaseOperator(metaclass=ABCMeta):
         self,
         user: UserInformation,
         driver: webdriver.remote.webdriver.WebDriver,
-        logger: Logger = getLogger(__name__),
+        logger: Logger = _logger,
     ):
         self._user = user
         self._driver = driver
@@ -31,8 +35,8 @@ class DriverCheckMixin:
         """Check whether self._driver is Chrome, Firefox or Edge
 
         Raises:
-            UnableActionException: Occurred when self._driver is not Chrome, Firefox or Edge  # noqa
-        """
+            UnableActionException: Occurred when self._driver is not Chrome, Firefox or Edge
+        """  # noqa
         if not (
             isinstance(self._driver, webdriver.Chrome)
             or isinstance(self._driver, webdriver.Firefox)
