@@ -1,11 +1,15 @@
-from bs4 import BeautifulSoup
 import datetime
 
+from bs4 import BeautifulSoup
+
 grade_mapper = {
     'is-ippan': 'ippan',
     'is-G3b': 'G3',
     'is-G2b': 'G2',
     'is-G1b': 'G1',
+    'is-G3a': 'G3',
+    'is-G2a': 'G2',
+    'is-G1a': 'G1',
     'is-SGa': "SG",
     'is-lady': 'lady',
     'is-venus': 'venus',
@@ -19,6 +23,8 @@ timeframe_mapper = {
     'is-summer': 'summer',
     'is_nighter': 'nighter',
     'is-nighter': 'nighter',
+    'is_midnight': 'midnight',
+    'is-midnight': 'midnight',
 }
 
 
@@ -107,12 +113,12 @@ def parse_html_index(html: str):
 
     # extract date
     d = datetime.datetime.strptime(
-        soup.select_one('p.btnGroup3_refreshBtn > a')['href'].split('hd=')[-1],
+        soup.select_one('p.btnGroup3_refreshBtn > a')['href'].split('hd=')[-1],  # type: ignore  # noqa
         '%Y%m%d'
     )
 
     # table
-    table = soup.select_one('div.table1').select('table > tbody')
+    table = soup.select_one('div.table1').select('table > tbody')  # type: ignore  # noqa
 
     # parse
     dic = dict([
