@@ -1,14 +1,15 @@
 import datetime
 from logging import Logger, getLogger
-from selenium import webdriver
 from typing import Any, Dict
 
+from selenium import webdriver
 
-from .base import BaseScraper
 from ..const import BOATRACEJP_BASE_URL
+from ..validator import validate_date, validate_race, validate_stadium
 from ._parser import parse_html_racelist
-from ..validator import validate_date, validate_stadium, validate_race
+from .base import BaseScraper
 
+_logger: Logger = getLogger(__name__)
 
 class RaceInfoScraper(BaseScraper):
     """To get race information
@@ -19,7 +20,7 @@ class RaceInfoScraper(BaseScraper):
     def __init__(
         self,
         driver: webdriver.remote.webdriver.WebDriver,
-        logger: Logger = getLogger(__name__),
+        logger: Logger = _logger,
     ):
         super().__init__(driver, parse_html_racelist, logger)
 
