@@ -1,7 +1,10 @@
-import os
 import json
+import os
 from getpass import getpass
 from logging import Logger, getLogger
+from typing import Optional
+
+_logger: Logger = getLogger(__name__)
 
 
 class UserInformation:
@@ -16,18 +19,18 @@ class UserInformation:
 
     def __init__(
         self,
-        userid: str = None,
-        pin: str = None,
-        auth_pass: str = None,
-        vote_pass: str = None,  # TODO rename vote_pass -> bet_pass
-        json_file: str = None,
-        logger: Logger = getLogger(__name__)
+        userid: Optional[str] = None,
+        pin: Optional[str] = None,
+        auth_pass: Optional[str] = None,
+        vote_pass: Optional[str] = None,  # TODO rename vote_pass -> bet_pass
+        json_file: Optional[str] = None,
+        logger: Logger = _logger,
     ):
         # preparation
-        self.userid = None
-        self.pin = None
-        self.auth_pass = None
-        self.vote_pass = None
+        self.userid: Optional[str] = None
+        self.pin: Optional[str] = None
+        self.auth_pass: Optional[str] = None
+        self.vote_pass: Optional[str] = None
 
         # load json
         if json_file is not None and os.path.exists(json_file):
